@@ -1,3 +1,4 @@
+#!/usr/bin/env python
 import sys
 
 # Try imports and report missing packages.
@@ -34,4 +35,7 @@ def run_app():
     viewer = Viewer(path)
     viewer.show()
 
-    sys.exit(app.exec_())
\ No newline at end of file
+    sys.exit(app.exec_())
+
+if __name__ == "__main__":
+    run_app()
\ No newline at end of file
