@@ -124,9 +124,20 @@ class Viewer(QtGui.QMainWindow):
         if dialog.exec_():
             self.load_files(os.path.join(str(dialog.selectedFiles()[0]), "*.dcm"))
 
+    def export_image(self):
+        file_name = QtGui.QFileDialog.getSaveFileName(
+            self,
+            "Save file",
+            os.path.expanduser("~/dicom-export.png"),
+            "PNG images (*.png)"
+        )
+        if file_name:
+            self._image.save(file_name)
+
     def build_menu(self): 
         self.file_menu = QtGui.QMenu('&File', self)
         self.file_menu.addAction('&Open directory', self.open_directory, QtCore.Qt.CTRL + QtCore.Qt.Key_O)
+        self.file_menu.addAction('&Export image', self.export_image, QtCore.Qt.CTRL + QtCore.Qt.Key_S)
         self.file_menu.addAction('&Quit', self.close, QtCore.Qt.CTRL + QtCore.Qt.Key_Q)      
 
         self.view_menu = QtGui.QMenu('&View', self)
@@ -184,7 +195,7 @@ class Viewer(QtGui.QMainWindow):
         data[data > 255] = 255
         data = data.astype(np.int8)
 
-        qimage = QtGui.QImage(data, data.shape[0], data.shape[1], QtGui.QImage.Format_Indexed8)
+        qimage = QtGui.QImage(data, data.shape[1], data.shape[0], QtGui.QImage.Format_Indexed8)
         return qimage  
 
     def get_coordinates(self, i, j):
@@ -305,10 +316,14 @@ class Viewer(QtGui.QMainWindow):
                 self.data = self.file.RescaleSlope * self.file.pixel_array + self.file.RescaleIntercept
             else:
                 self.data = self.file.pixel_array
-            self.image_position = np.array([float(t) for t in self.file.ImagePositionPatient])
+            try:
+                self.image_position = np.array([float(t) for t in self.file.ImagePositionPatient])
+            except:
+                self.image_position = np.array([1., 1., 1.])
             self.pixel_spacing = np.array([float(t) for t in self.file.PixelSpacing])
             self.setWindowTitle("pydiq: " + self._file_name)
-        except:
+        except BaseException as exc:
+            print exc
             self.file = None
             self.data = np.ndarray((0, 0), np.int8)
             self.update_image()
